<?php
/*
 *	Made by Partydragen
 *  https://github.com/partydragen/Nameless-Suggestions
 *  https://partydragen.com/
 *
 *  Suggestions class
 */
 
class Suggestions {
	private $_db;

	// Constructor, connect to database
	public function __construct() {
		$this->_db = DB::getInstance();
	}
	
	// Get Categories
	public function getCategories(){
		$categories = DB::getInstance()->query('SELECT * FROM nl2_suggestions_categories WHERE deleted = 0')->results();
		$category_array = array();
		
		foreach($categories as $category){
			$category_array[] = array(
				'id' => Output::getClean($category->id),
				'name' => Output::getClean($category->name),
				'link' => URL::build('/suggestions/category/' . $category->id . '-' . Util::stringToURL($category->name))
			);
		}
		return $category_array;
	}
	
	// Get Statuses
	public function getStatuses(){
		$statuses = DB::getInstance()->query('SELECT * FROM nl2_suggestions_statuses WHERE deleted = 0')->results();
		$status_array = array();
		
		foreach($statuses as $status){
			$status_array[] = array(
				'id' => Output::getClean($status->sid),
				'html' => Output::getClean($status->html)
			);
		}
		return $status_array;
	}
	
	// Get Recently updated
	public function getRecentlyUpdated($user, $timeago, $language, $limit = 10){
		$suggestions_query = $this->_db->query('SELECT * FROM nl2_suggestions WHERE deleted = 0 ORDER BY last_updated DESC LIMIT ' . $limit)->results();
		$suggestions_array = array();
		
		foreach($suggestions_query as $item){
			$suggestions_array[] = array(
				'title' => Output::getClean($item->title),
				'link' => URL::build('/suggestions/view/' . $item->id . '-' . Util::stringToURL($item->title)),
				'updated_rough' => $timeago->inWords(date('d M Y, H:i', $item->last_updated), $language->getTimeLanguage()),
				'updated' => date('d M Y, H:i', $item->last_updated),
				'updated_by_avatar' => $user->getAvatar($item->updated_by, "../", 64),
				'updated_by_username' => Output::getClean($user->idToNickname($item->updated_by)),
				'updated_by_style' => $user->getGroupClass($item->updated_by),
				'updated_by_link' => URL::build('/profile/' . Output::getClean($user->idToName($item->updated_by))),
			);
		}
		return $suggestions_array;
	}
}